@@ -1,28 +1,26 @@
 import logging
+from typing import Union
+
 import click
 
-from typing import Union
 from stactools.cli import registry
 
 
 def setup_logging(level: Union[str, int]) -> None:
-    logger = logging.getLogger('stactools')
+    logger = logging.getLogger("stactools")
     logger.setLevel(level)
 
     ch = logging.StreamHandler()
     ch.setLevel(level)
-    formatter = logging.Formatter('%(message)s')
+    formatter = logging.Formatter("%(message)s")
     ch.setFormatter(formatter)
 
     logger.addHandler(ch)
 
 
 @click.group()
-@click.option('-v', '--verbose', help=("Use verbose mode"), is_flag=True)
-@click.option('-q',
-              '--quiet',
-              help=("Use quiet mode (no output)"),
-              is_flag=True)
+@click.option("-v", "--verbose", help=("Use verbose mode"), is_flag=True)
+@click.option("-q", "--quiet", help=("Use quiet mode (no output)"), is_flag=True)
 def cli(verbose: bool, quiet: bool) -> None:
     logging_level = logging.INFO
     if verbose:
@@ -37,7 +35,7 @@ for create_subcommand in registry.get_create_subcommand_functions():
 
 
 def run_cli() -> None:
-    cli(prog_name='stac')
+    cli(prog_name="stac")
 
 
 if __name__ == "__main__":
